
[![image](http://img.shields.io/pypi/v/HavNegpy.svg)](https://pypi.python.org/pypi/HavNegpy/)

# HavNegpy

HavNegpy is a python fit package to anaylze dielectric spectroscopy data. 
HavNeg is an acronym for Havriliak and Negami function, and the fit module is written specifically to analyze the dielectric loss and real part of AC conductivity data.

# Installation
pip install HavNegpy

# Some fit examples

<img src="readme_figures/Figure_1.png" width="400"> <img src="readme_figures/Figure_2.png" width="400">
<img src="readme_figures/Figure_3.png" width="400">
<img src="readme_figures/Figure_4.png" width="400">






## AUTHOR

Mohamed Aejaz Kolmangadi 

## LOOKING FOR HELP?

Checkout the Tutorials here (https://github.com/mkolmang/Tutorials_HavNegpy)
